/******************************************************************************/
/*									GENERAL INFO			  				  */
/******************************************************************************/
/*

PROJECT 
	Paper: Is the Mediterranean the New Rio Grande?
	Authors: Gordon Hanson and Craig McIntosh

DO FILE
	Created: February 2016
	Updated: 19 May 16 by Julia Clark
	Inputs: migration_JEP_data_160414
	Outputs: Tables 1 & 2, Figures 3 & 4

*/

/******************************************************************************/
/*									SETUP					  				  */
/******************************************************************************/

	#delimit;
	clear all;
	set matsize 10000;
	set more off;

	global date 160516;
	global dir "~/Dropbox/Migration_JEP/Migration_JEP_replication/";
	global data "data_clean/migration_JEP_data_$date";
	global covars "lbrat lgdprat lgdp15rat contig comlang_ethno colony ldist";

	*ssc install outreg2

/******************************************************************************/
/*									ANALYSIS				  				  */
/******************************************************************************/


/* TABLE 1: Counting First-Generation Migrants in 2010 */

	/* Panel A. Migrant counts by most common destination */
	#delimit;
	use "$dir/$data", clear;
	keep if year==2010;
	collapse (sum) number  des_pop origin_pop (first) iso_d, by(dyad_id);
	collapse (sum) number (mean) des_pop, by(iso_d);
	egen num_tot = sum(number);
	gsort -number;
	format number %12.0g;
	format des_pop %12.0g;
	gen dest_frac = number/des_pop;
	gen number_frac = number/num_tot;
	drop if _n>10;
	order iso_d  number dest_frac  number_frac;
	export delimited using "$dir/output/table1a.csv", replace;
	
	/* Panel B. Migrant counts by origin */
	#delimit;
	use "$dir/$data", clear;
	keep if year==2010;
	collapse (sum) number  des_pop origin_pop (first) iso_o, by(dyad_id);
	collapse (sum) number (mean) origin_pop, by(iso_o);
	egen num_tot = sum(number);
	gsort -number;
	format number %12.0g;
	format origin_pop %12.0g;
	gen origin_frac = number/origin_pop;
	gen number_frac = number/num_tot;
	drop if _n>3;
	order iso_o  number origin_frac  number_frac;
	export delimited using "$dir/output/table1b.csv", replace;
	
	/* Panel C. Migrant counts by origin/destination dyad */
	#delimit;
	use "$dir/$data", clear;
	keep if year==2010;
	collapse (sum) number  des_pop origin_pop (first) iso_o iso_d, by(dyad_id);
	egen num_tot = sum(number);
	drop if number==0;
	gsort -number;
	format number %12.0g;
	format des_pop %12.0g;
	format origin_pop %12.0g;
	gen origin_frac = number/origin_pop;
	gen dest_frac = number/des_pop;
	gen number_frac = number/num_tot;
	egen billy = rank(number), by(iso_d) field;
	*drop if billy>3;
	keep if (iso_d=="USA" | iso_d=="DEU" | iso_d=="ITA" | iso_d=="FRA" | iso_d=="ESP" | iso_d=="MEX" | iso_d=="GBR");  
	drop dyad_id;
	gsort -iso_d -number;
	order iso_d iso_o number dest_frac origin_frac number_frac;
	export delimited using "$dir/output/table1c.csv", replace;

/* TABLE 2: The Heterogeneity of Labor Supply Growth by Dyad Characteristics */
/* Interaction effects using changes in migration and the lagged cohort ratio changes on the RHS */
	#delimit;
	use "$dir/$data", clear;
	set more off;
	preserve;
	gen intervar = mig_kernel_lo;
	gen inter = lbrat_dif10 * mig_kernel_lo;
	reg dmigpercm lbrat_dif10 i.id_o i.id_d i.id_bcohort i.female ldist contig colony comlang_ethno lgdp15rat 
		if sample_PANEL==1 & year==2000 [aw = origin_base_pop], cluster(bcohort_id);
		outreg2 using "$dir/output/table2", keep(lbrat_dif10 ldist contig colony comlang_ethno lgdp15rat) ctitle("mig_kernel_lo")  se replace;
	reg dmigpercm inter lbrat_dif10 intervar i.id_o i.id_d  i.id_bcohort i.female ldist contig colony comlang_ethno lgdp15rat 
		if sample_PANEL==1 & year==2000 [aw = origin_base_pop], cluster(bcohort_id);
		test inter+lbrat_dif10=0;
		outreg2 using "$dir/output/table2", keep(inter lbrat_dif10 intervar ldist contig colony comlang_ethno lgdp15rat) addstat(F test: inter+lbrat_dif10=0, r(F), Prob > F, r(p))  ctitle("mig_kernel_lo")  se append;
	foreach x in mig_kernel_med mig_kernel_hi ldist contig colony comlang_ethno {;
		replace intervar = `x';   
		replace inter = lbrat_dif10 * `x';
		reg dmigpercm inter lbrat_dif10 intervar i.id_o i.id_d  i.id_bcohort i.female ldist contig colony comlang_ethno lgdp15rat 
			if sample_PANEL==1 & year==2000 [aw = origin_base_pop], cluster(bcohort_id);
			test inter+lbrat_dif10=0;
			outreg2 using "$dir/output/table2", keep(inter lbrat_dif10 intervar ldist contig colony comlang_ethno lgdp15rat) addstat(F test: inter+lbrat_dif10=0, r(F), Prob > F, r(p)) ctitle("`x'")  se append;
		};
	restore;	


/* FIGURE 3: Predicted Migration by Destination (graph generated in Excel) */
	#delimit;
	use "$dir/$data", clear;
	collapse (sum) number_hat  des_pop origin_pop (first) iso_d, by(dyad_id year);
	collapse (sum) number_hat , by(iso_d year);
	keep if (iso_d=="JPN" | iso_d=="DEU" | iso_d=="FRA" | iso_d=="USA" | iso_d=="GBR" | iso_d=="ITA" | iso_d=="ESP");
	replace number_hat = number_hat/1000000;
	reshape wide number_hat, i(iso_d) j(year);
	export delimited using "$dir/output/figure3data.csv", replace;
		

/* FIGURE 4: Migration Projections by Origin and Destination*/
	
	/* Migration to USA */
	#delimit;
	use "$dir/$data", clear;
	foreach x in USA {;
		preserve;
		keep if iso_d=="`x'";
		collapse (sum) number_hat  des_base_pop origin_base_pop, by(origin_group_USA year);
		replace number_hat = number_hat/1000000;
		foreach y in India China Mexico SSA MENA Other {;
			gen orig_`y' = number_hat if origin_group=="`y'";
			};
		sort year;
		tw line orig_India year, lpattern(solid) || line orig_China year, lpattern(dot) || line orig_Mexico year, lpattern(dash) || line orig_SSA year, lpattern(dash_dot) ||
			line orig_MENA year, lpattern(shortdash) || line orig_Other year, lpattern(longdash_dot) title("Migration to `x', by Origin Region")
				legend(label(1 "India") label(2 "China") label(3 "Mexico") label(4 "Sub-Saharan Africa") label(5 "MENA") label(6 "All Other")) ytitle("Millions");
				graph export "$dir/output/figure4`x'.pdf", replace;
		restore;
		};	
	
	/* Migration to DEU GBR FRA ITA ES */
	#delimit;
	set more off;
	foreach x in DEU GBR FRA ITA ESP {;
		preserve;
		keep if iso_d=="`x'";
		collapse (sum) number_hat  des_base_pop origin_base_pop, by(origin_group_EUR year);
		replace number_hat = number_hat/1000000;
		foreach y in India China E_Europe SSA MENA Other {;
			gen orig_`y' = number_hat if origin_group=="`y'";
			};
		sort year;
		tw line orig_India year, lpattern(solid) || line orig_China year, lpattern(dot) || line orig_E_Europe year, lpattern(dash) || line orig_SSA year, lpattern(dash_dot) ||
			line orig_MENA year, lpattern(shortdash) || line orig_Other year, lpattern(longdash_dot) title("Migration to `x', by Origin Region")
				legend(label(1 "India") label(2 "China") label(3 "Eastern Europe") label(4 "Sub-Saharan Africa") label(5 "MENA") label(6 "All Other")) ytitle("Millions");
				graph export "$dir/output/figure4`x'.pdf", replace;
		restore;
		};	
	
	/* Migration to JPN */
	#delimit;
	foreach x in JPN  {;
		preserve;
		keep if iso_d=="`x'";
		collapse (sum) number_hat  des_base_pop origin_base_pop, by(origin_group_JAP year);
		replace number_hat = number_hat/1000000;
		foreach y in India China Korea SSA MENA Other {;
			gen orig_`y' = number_hat if origin_group=="`y'";
			};
		sort year;
		tw line orig_India year, lpattern(solid) || line orig_China year, lpattern(dot) || line orig_Korea year, lpattern(dash) || line orig_SSA year, lpattern(dash_dot) ||
			line orig_MENA year, lpattern(shortdash) || line orig_Other year, lpattern(longdash_dot) title("Migration to `x', by Origin Region")
				legend(label(1 "India") label(2 "China") label(3 "Korea") label(4 "Sub-Saharan Africa") label(5 "MENA") label(6 "All Other")) ytitle("Millions");
				graph export "$dir/output/figure4`x'.pdf", replace;
		restore;
		};	

	
	

